==> coderider-kilo-jetbrains-2.3.3-2024-2025.zip: coderider-kilo-jetbrains/coderider-kilo/CHANGELOG.md <==
# 变更日志
### 版本：v2.3.6 (2025-12-4)
- 多窗口任务执行优化，任务模式解耦
- 修复 Issue 中 “AI 执行”问题、MR 中”代码审核“问题
- 修复 Issue 更新同步问题
### 版本：v2.3.5 (2025-11-28)
- 支持启用多窗口并行执行任务，提升工作效率。
- 上线登录邀请码，有效邀请码用户将获得额外权益。
- 优化“增强提示词”功能返回速度。
- 优化补全上下文截取方式，防止上下文越界。
- 新增插件公告模块，及时获取产品更新动态。

## 版本：v2.3.4 (2025-11-21)
- 修复“思考信息”折叠不生效问题。
- 修复部分数据埋点问题。

## 版本：v2.3.3 (2025-11-19)
- 修复内联操作出错问题及模型调用报错问题。
- 修复 Windows 系统中终端乱码问题。
- 修复官方多模型展示问题。
- 修复 AI DevOps 合并请求无法获取问题。
- 修复命令面板部分功能无法调用问题。
- 修复智能体编程上下文超限问题。

## 版本 v2.3.2 (2025-11-13)
- 支持通过 VSCode 命令面板唤起快捷指令调用
- 官方模型支持多模型切换，并上线 MiniMax-M2、GLM 4.6、DeepSeek v3.1 模型支持用户使用
- 部分已知问题修复。

## 版本：v2.3.1 (2025-11-12)
- 修复部分已知问题，包含登录、存储路径等。

## 版本：v2.3.0 (2025-11-10)

- CodeRider-Kilo 发布，具备以下功能：
- 生成代码：根据自然语言描述生成代码
- 重构与调试：优化现有代码并修复问题
- 编写与更新：创建和更新文档
- 回答问题：解答关于代码库的疑问
- 自动化：自动化重复性任务
- 创建：新建文件和项目
## 版本：v2.2.3 (2025-9-4)

- 修复数据埋点问题。

## 版本：v2.2.2 (2025-8-29)

- 修复 mermaid 渲染问题。
- 支持 Chat 上下文动态裁剪。
- 修复 Rules 功能使用问题。
- 修复模型配置、Loom 数据等问题。

## 版本：v2.2.1 (2025-8-15)

- 修复主题色适配问题。

## 版本：v2.2.0 (2025-8-14)

- Rules 功能发布，包含项目规则、用户规则。同时支持 Admin 管理员为企业成员配置项目规则模版。
- 支持用户配置第三方模型供 Loom 和 Chat 对话使用。
- 数据埋点更新，丰富内联操作和 Loom 功能数据。
- 知识库功能全面升级，提升知识库创建、更新速度，提升回复准确性。
- 私有化部署客户 Loom 模型升级。

## 版本：v2.1.3 (2025-7-23)

- 功能数据埋点更新。
- 安全声明内容企业管理员可配置。

## 版本：v2.1.2 (2025-6-25)

- 修复新用户登录问题。

## 版本：v2.1.1 (2025-6-24)

- 知识库创建支持取消。
- Loom 模型独立并支持配置。
- 功能优化与缺陷修复：插件登出、优化 Loom 推荐任务、优化 Loom 上下文管理等。

## 版本：v2.1.0(2025-5-16)

- 增加代码补全延时可配置功能。
- 优化单元测试文件路径问题。
- 优化其他问题，如：个人指令创建、焦点文件获取、部分报错信息优化等。

## 版本：v2.0.0 (2025-4-16)

发布 CodeRider Loom，支持：
- 复杂任务拆解与分析：自动分解复杂编程任务，生成可执行的子任务方案，并提供优化建议。
- 跨文件读取、编辑代码文件：支持跨多个文件解析和修改代码，实现智能代码生成与重构。
- 错误信息自反馈与纠正：自动捕捉错误信息，分析根因并生成修复建议，优化代码质量。
- 终端指令执行：智能解析和执行终端指令，辅助开发者高效完成环境配置与调试操作。
## 版本：v1.9.3 (2025-3-31)

- 优化对话渲染效果，支持图表可视化。
- 优化代码补全效果，跨文件检索更精准。
- 优化补全模式，默认为动态补全策略，根据光标位置自适应单行、多行补全代码建议。
- 支持对话框快捷指令触发代码文件编辑，包含：代码修改、单元测试、代码注释、代码优化。

## 版本：v1.9.2 (2025-2-25)

- 功能优化与缺陷修复。

## 版本：v1.9.1 (2025-2-16)

- 提示词优化。

## 版本：v1.9.0 (2025-2-14)

- 推理模型适配，对话功能支持使用“深度思考”模式。

- 其他功能优化与缺陷修复。

## 版本：v1.8.1 (2025-1-14)

- 缺陷修复：中英文显示与配置问题、长对话渲染卡顿问题。

## 版本：v1.8.0 (2025-1-10)

- 对话功能，支持在对话框中“/清除记忆”来清空当前对话上下文。

- 指令内联操作，支持通过快捷键（option+k - macOS 或 alt+k - Windows）唤醒内联操作，并提供在编辑器中的对比显示。

- 优化知识库创建流程，支持针对不同代码分支创建知识库，并显示创建进度。

- 私有化部署用户新增企业管理员自定义“企业指令”。

- 支持设置默认对话输出语言。

- 其他功能优化与缺陷修复，如代码补全、前端渲染、登录、 commit message 生成、pre-review 等。

## 版本：v1.7.0 (2024-11-21)

- 插件交互方式优化。

- 新增用户快捷指令自定义功能。

- 项目引导功能。

- 指令内联操作。

- 生成提交信息。

- 提交代码变更前预审核。

- 企业级别知识库配置（私有化部署方案）。

- 效能数据看板。

- 增加代码单行补全模式。

## 版本：v1.6.1 (2024-10-22)

- 私有模型权限升级，为企业私有化部署用户带来极致编程体验。

- 代码评审 Agent 上线。

- 修复缺陷。

## 版本：v1.6.0 (2024-10-12)

- 代码库知识问答：基于代码库的知识问答功能上线，智能解答项目代码相关问题，提升协作效率。

- 智能代码补全增强：智能代码补全功能进一步增强，基于代码库内容精准推荐，且云端模型全新升级，助力开发者提高编写效率。

## 版本：v1.5.0 (2024-9-20)

- AI 代码审核功能升级：全面升级智能代码审核，对合并请求（MR）进行全方位文件级分析，提供多维度的评审建议与优化方案，显著提升代码审核的效率与质量，助力开发团队实现高效协作与代码质量保障。

- 登录方式优化：提供灵活便捷的登录方式，简化用户的登录流程，同时显著提升账号安全性，为用户提供更加便捷与安全的使用体验。

- 云端模型性能升级：全面优化云端模型的性能，大幅提升响应速度和代码建议的准确性，为用户提供更加高效的智能研发辅助体验。

## 版本：v1.4.0 （2024-8-30）

- 企业知识库：提供基于云端模型的企业级知识库功能，以企业文档为基础进行技术问答，显著提升企业文档的利用效率。

- AI 辅助编程优化：针对代码补全技术方案进行优化，通过利用更多的代码文件，进一步提升代码补全的性能。

- 模型与知识库配置：支持用户配置代码补全和对话的模型引擎，同时具备针对知识库的增删查改配置功能。

## 版本：v1.3.5 (2024-7-16)

- 基于云端算力模型的 CodeRier 产品发布，支持基于云端算力的代码补全、技术问答、辅助编程、Issue 和 MR 的处理等功能；

- 支持全球统一用户登录，用户可随时随地访问和管理个人项目，无需多重验证，确保开发过程高效便捷，提升工作灵活性。

## 版本：v1.1.0（2024-6-18）

- 国际版 CodeRider 发布，支持香港的极狐GitLab SaaS 用户试用，软件功能支持双语。

## 版本：v1.0.0 (2024-05-28)

- 智能 DevOps 助手：处理议题、处理合并请求、管理流水线、处理与我相关的任务、GitLab 快捷操作命令；

- 智能辅助编程：代码补全、代码生成、代码解释、代码注释、代码修改、单元测试、代码优化；

- 智能问答：自然语言问答、GitLab 文档问答。

==> coderider-kilo-jetbrains-2.3.5-2024-2025.zip: coderider-kilo-jetbrains/coderider-kilo/CHANGELOG.md <==
# 变更日志

## 版本：v2.3.8 (2025-12-19)
- GitLab MCP 上线，支持代码仓、议题、合并请求等管理
- 多模态功能上线，支持根据图片生成代码、排查报错问题等
- 内联操作优化，内联操作语言设置优化
- YOLO 模式优化，加入 Safety Gatekeeper 在自动批准之前决定是否允许有风险的操作

## 版本：v2.3.7 (2025-12-12)
- 新增 YOLO 模式，在该模式下所有审批请求将会自动获得批准
- 优化大型项目 @文件搜索功能
- 改进 XLSX 支持
- MiniMax-M2 推理块保持，提升模型性能
- 前台长期运行进程和交互式命令使用 VSCode 集成终端运行
- 修复基于 MiniMax-M2 模型生成提交信息含有推理模式问题
- 文件级 AI CodeReview 单个文件审核支持15万字符限制

## 版本：v2.3.6 (2025-12-4)
- 多窗口任务执行优化，任务模式解耦
- 修复 Issue 中 “AI 执行”问题、MR 中”代码审核“问题
- 修复 Issue 更新同步问题

## 版本：v2.3.5 (2025-11-28)
- 支持启用多窗口并行执行任务，提升工作效率。
- 上线登录邀请码，有效邀请码用户将获得额外权益。
- 优化“增强提示词”功能返回速度。
- 优化补全上下文截取方式，防止上下文越界。
- 新增插件公告模块，及时获取产品更新动态。

## 版本：v2.3.4 (2025-11-21)
- 修复“思考信息”折叠不生效问题。
- 修复部分数据埋点问题。

## 版本：v2.3.3 (2025-11-19)
- 修复内联操作出错问题及模型调用报错问题。
- 修复 Windows 系统中终端乱码问题。
- 修复官方多模型展示问题。
- 修复 AI DevOps 合并请求无法获取问题。
- 修复命令面板部分功能无法调用问题。
- 修复智能体编程上下文超限问题。

## 版本 v2.3.2 (2025-11-13)
- 支持通过 VSCode 命令面板唤起快捷指令调用
- 官方模型支持多模型切换，并上线 MiniMax-M2、GLM 4.6、DeepSeek v3.1 模型支持用户使用
- 部分已知问题修复。

## 版本：v2.3.1 (2025-11-12)
- 修复部分已知问题，包含登录、存储路径等。

## 版本：v2.3.0 (2025-11-10)

- CodeRider-Kilo 发布，具备以下功能：
- 生成代码：根据自然语言描述生成代码
- 重构与调试：优化现有代码并修复问题
- 编写与更新：创建和更新文档
- 回答问题：解答关于代码库的疑问
- 自动化：自动化重复性任务
- 创建：新建文件和项目
## 版本：v2.2.3 (2025-9-4)

- 修复数据埋点问题。

## 版本：v2.2.2 (2025-8-29)

- 修复 mermaid 渲染问题。
- 支持 Chat 上下文动态裁剪。
- 修复 Rules 功能使用问题。
- 修复模型配置、Loom 数据等问题。

## 版本：v2.2.1 (2025-8-15)

- 修复主题色适配问题。

## 版本：v2.2.0 (2025-8-14)

- Rules 功能发布，包含项目规则、用户规则。同时支持 Admin 管理员为企业成员配置项目规则模版。
- 支持用户配置第三方模型供 Loom 和 Chat 对话使用。
- 数据埋点更新，丰富内联操作和 Loom 功能数据。
- 知识库功能全面升级，提升知识库创建、更新速度，提升回复准确性。
- 私有化部署客户 Loom 模型升级。

## 版本：v2.1.3 (2025-7-23)

- 功能数据埋点更新。
- 安全声明内容企业管理员可配置。

## 版本：v2.1.2 (2025-6-25)

- 修复新用户登录问题。

## 版本：v2.1.1 (2025-6-24)

- 知识库创建支持取消。
- Loom 模型独立并支持配置。
- 功能优化与缺陷修复：插件登出、优化 Loom 推荐任务、优化 Loom 上下文管理等。

## 版本：v2.1.0(2025-5-16)

- 增加代码补全延时可配置功能。
- 优化单元测试文件路径问题。
- 优化其他问题，如：个人指令创建、焦点文件获取、部分报错信息优化等。

## 版本：v2.0.0 (2025-4-16)

发布 CodeRider Loom，支持：
- 复杂任务拆解与分析：自动分解复杂编程任务，生成可执行的子任务方案，并提供优化建议。
- 跨文件读取、编辑代码文件：支持跨多个文件解析和修改代码，实现智能代码生成与重构。
- 错误信息自反馈与纠正：自动捕捉错误信息，分析根因并生成修复建议，优化代码质量。
- 终端指令执行：智能解析和执行终端指令，辅助开发者高效完成环境配置与调试操作。
## 版本：v1.9.3 (2025-3-31)

- 优化对话渲染效果，支持图表可视化。
- 优化代码补全效果，跨文件检索更精准。
- 优化补全模式，默认为动态补全策略，根据光标位置自适应单行、多行补全代码建议。
- 支持对话框快捷指令触发代码文件编辑，包含：代码修改、单元测试、代码注释、代码优化。

## 版本：v1.9.2 (2025-2-25)

- 功能优化与缺陷修复。

## 版本：v1.9.1 (2025-2-16)

- 提示词优化。

## 版本：v1.9.0 (2025-2-14)

- 推理模型适配，对话功能支持使用“深度思考”模式。

- 其他功能优化与缺陷修复。

## 版本：v1.8.1 (2025-1-14)

- 缺陷修复：中英文显示与配置问题、长对话渲染卡顿问题。

## 版本：v1.8.0 (2025-1-10)

- 对话功能，支持在对话框中“/清除记忆”来清空当前对话上下文。

- 指令内联操作，支持通过快捷键（option+k - macOS 或 alt+k - Windows）唤醒内联操作，并提供在编辑器中的对比显示。

- 优化知识库创建流程，支持针对不同代码分支创建知识库，并显示创建进度。

- 私有化部署用户新增企业管理员自定义“企业指令”。

- 支持设置默认对话输出语言。

- 其他功能优化与缺陷修复，如代码补全、前端渲染、登录、 commit message 生成、pre-review 等。

## 版本：v1.7.0 (2024-11-21)

- 插件交互方式优化。

- 新增用户快捷指令自定义功能。

- 项目引导功能。

- 指令内联操作。

- 生成提交信息。

- 提交代码变更前预审核。

- 企业级别知识库配置（私有化部署方案）。

- 效能数据看板。

- 增加代码单行补全模式。

## 版本：v1.6.1 (2024-10-22)

- 私有模型权限升级，为企业私有化部署用户带来极致编程体验。

- 代码评审 Agent 上线。

- 修复缺陷。

## 版本：v1.6.0 (2024-10-12)

- 代码库知识问答：基于代码库的知识问答功能上线，智能解答项目代码相关问题，提升协作效率。

- 智能代码补全增强：智能代码补全功能进一步增强，基于代码库内容精准推荐，且云端模型全新升级，助力开发者提高编写效率。

## 版本：v1.5.0 (2024-9-20)

- AI 代码审核功能升级：全面升级智能代码审核，对合并请求（MR）进行全方位文件级分析，提供多维度的评审建议与优化方案，显著提升代码审核的效率与质量，助力开发团队实现高效协作与代码质量保障。

- 登录方式优化：提供灵活便捷的登录方式，简化用户的登录流程，同时显著提升账号安全性，为用户提供更加便捷与安全的使用体验。

- 云端模型性能升级：全面优化云端模型的性能，大幅提升响应速度和代码建议的准确性，为用户提供更加高效的智能研发辅助体验。

## 版本：v1.4.0 （2024-8-30）

- 企业知识库：提供基于云端模型的企业级知识库功能，以企业文档为基础进行技术问答，显著提升企业文档的利用效率。

- AI 辅助编程优化：针对代码补全技术方案进行优化，通过利用更多的代码文件，进一步提升代码补全的性能。

- 模型与知识库配置：支持用户配置代码补全和对话的模型引擎，同时具备针对知识库的增删查改配置功能。

## 版本：v1.3.5 (2024-7-16)

- 基于云端算力模型的 CodeRier 产品发布，支持基于云端算力的代码补全、技术问答、辅助编程、Issue 和 MR 的处理等功能；

- 支持全球统一用户登录，用户可随时随地访问和管理个人项目，无需多重验证，确保开发过程高效便捷，提升工作灵活性。

## 版本：v1.1.0（2024-6-18）

- 国际版 CodeRider 发布，支持香港的极狐GitLab SaaS 用户试用，软件功能支持双语。

## 版本：v1.0.0 (2024-05-28)

- 智能 DevOps 助手：处理议题、处理合并请求、管理流水线、处理与我相关的任务、GitLab 快捷操作命令；

- 智能辅助编程：代码补全、代码生成、代码解释、代码注释、代码修改、单元测试、代码优化；

- 智能问答：自然语言问答、GitLab 文档问答。
